@@ -10,8 +10,12 @@
 package Language::Befunge::Ops;
 require 5.006;
 
+use strict;
+use warnings;
+
 use Config;   # For the 'y' instruction.
 
+
 =head1 NAME
 
 Language::Befunge::Ops - definition of the various operations
